import Taro, { Component } from '@tarojs/taro';
import ListView from '@components/ListView'
import { connect } from '@tarojs/redux'
import './index.scss'
import { getSharePersonList } from '@services/person'
import { savePoint, updatePoint } from '@services/common'
import { transferImage } from '@utils/tools'


@connect(state => state.user)

export default class Person extends Taro.Component {
  config = {
    navigationBarTitleText: '我的分享'
  }

  state = {
    recordId: undefined, // 埋点ID
    recordList: [],
    hasMore: true,
    isEmpty: false,
    pageIndex: 1,
  }

  componentWillMount() {

    savePoint({
      event: 'list',
      eventType: 'activity',
      propertyName: '我的分享',
      data: '{}'
    }).then(res => {
      this.setState({
        recordId: res.recordId
      })
      console.log('我的分享')
    })
  }
  componentWillUnmount() {
    const { recordId } = this.state
    recordId && updatePoint(recordId)
  }

  loadList(pageNumber) {
    const { userInfo: { person } } = this.props

    let payload
    if (person.userId) {
      payload = {
        userId: person.userId,
        pageNumber,
        pageSize: 10
      }
    } else {
      payload = {
        userId: Taro.getStorageSync('userId'),
        pageNumber,
        pageSize: 10
      }
    }
    getSharePersonList(payload).then(res => {

      const { records, list, total, current, pages } = res || {}
      const _list = records || list || []
      const newList = current <= 1 ? _list : this.state.recordList.concat(_list)

      this.setState({
        recordList: newList,
        isEmpty: total == 0,
        hasMore: current < pages,
        pageIndex: current >= pages ? pages : current
      })
      Taro.hideLoading()
    })
  }
  onScrollToLower = async (fn) => {
    const { pageIndex } = this.state;
    this.loadList(pageIndex + 1)
    fn && fn();
  }
  onPullDownRefresh = (rest) => {
    // debugger
    if (this.refreshing) return
    this.refreshing = true
    this.loadList(1)
    rest && rest()
    this.refreshing = false
  }

  handleItemClick(targetId) {
    Taro.navigateTo({
      url: `/pages/person/myShare/accessRecord?targetId=` + targetId
    })
  }

  renderBuilding(item) {
    return (
      <View className="share-item" onClick={this.handleItemClick.bind(this, item.targetId)}>
        <Image className="img" src={transferImage(item.drainageImg)}></Image>
        <View className="building">{item.buildingName}</View>
        <View className="price"> 均价{item.price ? item.price : ''}元/m² </View>
        <View className="num"> {item.buildingNum ? item.buildingNum : '0'}人查看了分享 </View>
        <View className="address"> {item.address} </View>
      </View>
    )
  }

  renderH5(item) {
    return (
      <View className="share-item" onClick={this.handleItemClick.bind(this, item.targetId)}>
        <Image className="img" src={transferImage(item.drainageImg)}></Image>
        <View className="name">{item.drainageName}</View>
        <View className="num"> {item.drainageShareNum ? item.drainageShareNum : '0'}人查看了分享 </View>
      </View>
    )
  }

  renderGroup(item) {
    return (
      <View className="share-item" onClick={this.handleItemClick.bind(this, item.targetId)}>
        <Image className="img" src={transferImage(item.groupActivityImg)}></Image>
        <View className="name">{item.groupActivityName}</View>
        <View className="num"> {item.groupActivityShareNum ? item.groupActivityShareNum : '0'}人查看了分享 </View>
      </View>
    )
  }

  renderHelp(item) {
    return (
      <View className="share-item" onClick={this.handleItemClick.bind(this, item.targetId)}>
        <Image className="img" src={transferImage(item.helpActivityImg)}></Image>
        <View className="name">{item.helpActivityName}</View>
        <View className="num"> {item.helpActivityShareNum ? item.helpActivityShareNum : '0'}人查看了分享 </View>
      </View>
    )
  }

  renderNews(item) {
    return (
      <View className="share-item" onClick={this.handleItemClick.bind(this, item.targetId)}>
        <Image className="img" src={transferImage(item.newsImg)}></Image>
        <View className="name">{item.newsName}</View>
        <View className="num"> {item.newsNum ? item.newsNum : '0'}人查看了分享 </View>
      </View>
    )
  }

  renderActivity(item) {
    return (
      <View className="share-item" onClick={this.handleItemClick.bind(this, item.targetId)}>
        <Image className="img" src={transferImage(item.activityImg)}></Image>
        <View className="name">{item.activityName}</View>
        <View className="num"> {item.activityShareNum ? item.activityShareNum : '0'}人查看了分享 </View>
      </View>
    )
  }


  render() {
    const { isEmpty, hasMore, recordList } = this.state
    return (
      <ListView
        className="wrap"
        needInit
        isEmpty={isEmpty}
        emptyText="暂无我的分享~"
        hasMore={hasMore}
        onPullDownRefresh={fn => this.onPullDownRefresh(fn)}
        onScrollToLower={fn => this.onScrollToLower(fn)}
      >
        <View className="list" >
          {
            recordList.map(item => (
              <View key={item.targetId + 'share'} className='share-page'>
                {item.shareType == 'building' && this.renderBuilding(item)}
                {item.shareType == 'h5' && this.renderH5(item)}
                {item.shareType == 'group' && this.renderGroup(item)}
                {item.shareType == 'help' && this.renderHelp(item)}
                {item.shareType == 'news' && this.renderNews(item)}
                {item.shareType == 'activity' && this.renderActivity(item)}
              </View>
            ))
          }
        </View>
      </ListView>
    )
  }
}
